#!/bin/sh

set +e

###############################################################################
# Licensed Materials - Property of Tivoli Systems
# 5697-GEM
# (C) COPYRIGHT Tivoli Systems, an IBM Company 1997, 1998
# All rights reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################
#
#  Install a product's console instance
###############################################################################
DBUG=1

echo "Invocation: $0 $@"

###############################################################################
# Run the standard script to set up the Tivoli environment
###############################################################################
if [ -n "$windir" ] ; then
      WINOS=`echo $windir | awk /:/'{ print substr($1,4) }'`
   WINDRIVE=`echo $windir | awk /:/'{ print substr($1,1,2) }'`
fi

if [ -n "$WINOS" ]
then source $WINDRIVE/$WINOS/system32/drivers/etc/Tivoli/setup_env.sh
else . /etc/Tivoli/setup_env.sh
fi

###############################################################################
# Locate GEM installation root"
###############################################################################
root=$BINDIR/../generic_unix/TDS/client
root2=$BINDIR/../generic_unix/TDS

###############################################################################
# We MUST be passed the "key" of the product to be installed
###############################################################################
key=$1
key=${key:?"product \"key\" not supplied!"}

tdiKey="$key"

###############################################################################
# The product properties file for the "key" must exist
###############################################################################
prodProp="$root/lib/${key}.properties"

if [ ! -f $prodProp ] ; then
  echo
  echo "The product properties file for $key does not exist!"
  echo "==> $prodProp"
  exit 1
fi

if [ $DBUG -eq 1 ]
then
  echo "---------------------------------------------------------"
  cat $prodProp    # dump contents for debugging
  echo "---------------------------------------------------------"
  echo
fi

###############################################################################
# Load Tivoli Desktop Installation values from the product properties file
###############################################################################
   tdiClass=`awk -F=    /'^tdiClass'/'{print $2}' $prodProp`
 tdiPatchID=`awk -F=  /'^tdiPatchID'/'{print $2}' $prodProp`
    tdiIcon=`awk -F=     /'^tdiIcon'/'{print $2}' $prodProp`
tdiAboutCat=`awk -F= /'^tdiAboutCat'/'{print $2}' $prodProp`

###############################################################################
# Set default values
###############################################################################
    tdiIcon=${tdiIcon:="tconsole.xpm"}

###############################################################################
# Dump Tivoli Desktop Installation values
###############################################################################
echo "tdiKey      =$tdiKey"
echo "tdiClass    =$tdiClass"
echo "tdiPatchID  =$tdiPatchID"
echo "tdiIcon     =$tdiIcon"
echo "tdiAboutCat =$tdiAboutCat"
echo

###############################################################################
# Establish runtime constants
###############################################################################
    icon=$root/icons/$tdiIcon
aboutCat=$root/bin/$tdiAboutCat

###############################################################################
# Has the product's class already been created?
###############################################################################
classOID=`wlookup -r Classes $tdiClass 2> /dev/null`

if [ -z "$classOID" ] ; then

   ############################################################################
   # Create the console class
   ############################################################################
   lib=`wlookup Library`

   set -e

   classOID=`objcall $lib create_class_cli -c -p imp_TNR::Base -p \
      TMF_imp_TSysAdmin::PolicyDrivenBase \
      -m imp_TNR::InstanceManager $tdiClass`

   echo Created $tdiClass class with OID=$classOID

   set_friendly_name $classOID $tdiClass

   if [ $DBUG -eq 1 ]; then echo "Set friendly name for $tdiClass class..."; fi

   ############################################################################
   # Create console class' presentation
   ############################################################################
   initpres $classOID -class -create parent Collection \
      state normal                  $root/bin/console.d \
      xpm                           $icon \
      dialog properties_dialog      $root/bin/properties.d  \
      dialog properties_help_dialog $root/bin/propertiesHelp.d

   if [ $DBUG -eq 1 ]; then echo "Set initpres..."; fi

   inituiattrs $classOID $tdiClass normal $tdiClass

   if [ $DBUG -eq 1 ]; then echo "Set inituiattrs..."; fi

   ############################################################################
   # Establish console class' methods
   #
   # - menu
   # - properties dialog
   ############################################################################

   # these relate to the console's icon and menu

   wputmeth -u "\$root_user" -g "" -r $tdiClass open               /../generic_unix/TDS/client/bin/openConsole.sh
   wputmeth -u "\$root_user" -g "" -r $tdiClass openProperties     /../generic_unix/TDS/client/bin/openProperties.sh

   # these relate to the properties dialog

   wputmeth -u "\$root_user" -g "" -r $tdiClass changeProperties   /../generic_unix/TDS/client/bin/changeProperties.sh
   wputmeth -u "\$root_user" -g "" -r $tdiClass openPropertiesHelp /../generic_unix/TDS/client/bin/openPropertiesHelp.sh

   if [ $DBUG -eq 1 ]; then echo "Set wputmeth"; fi

   ############################################################################
   # Establish console class' bitmap
   ############################################################################
   wputbitmap                      -r $tdiClass client_icon < $icon

   if [ $DBUG -eq 1 ]; then echo "Set wputbitmap"; fi

   ############################################################################
   # Establish console class' "About" support
   ############################################################################
   set +e

   wsetabout $aboutCat 1 $tdiPatchID

   if [ $DBUG -eq 1 ]; then echo "Set ABOUT info for $tdiPatchID from $aboutCat"; fi

else

  echo "$tdiClass class already exists with OID=$classOID"

fi

###############################################################################
# Get object reference and name of the target ManagedNode
###############################################################################
set -e

 hostOID=`objcall 0.0.0 o_getattr HostLocation`

nodeName=`idlattr -t -g $hostOID label string`

set +e

###############################################################################
# Generate the label of the console object we will be creating
###############################################################################
label=`echo $nodeName | sed -e 's/^"//' -e 's/"$//'`
label="${tdiClass}_$label"

###############################################################################
# Has an instance of the console class already been created
# for this ManagedNode?
###############################################################################
consoleOID=`wlookup -r $tdiClass "$label" 2> /dev/null`

if [ -z "$consoleOID" ] ; then

   ############################################################################
   # Create an instance of the console class for the target ManagedNode
   ############################################################################
   consoleOID=`objcall $classOID _create_instance -h $hostOID -l "$label"`

   echo "Created $label instance with OID=$consoleOID"

   ############################################################################
   # Add created instance to administrator's collection
   ############################################################################
   ALI=`wlookup TME_server`
   ID=`objcall $ALI get_identity`

   if [ $DBUG -eq 1 ]; then echo "ID=$ID"; fi

   ROOTADMIN=`echo $ID | awk '{print $2}'`

   if [ $DBUG -eq 1 ]; then echo "ROOTADMIN=$ROOTADMIN"; fi

   idlcall $ROOTADMIN TMF_SysAdmin::Collection::add_object $consoleOID

   if [ $DBUG -eq 1 ]; then echo "Added console object to desktop collection"; fi

   idlcall $ROOTADMIN TMF_TGC::GenericCollection::refresh_collection refresh_collection

   if [ $DBUG -eq 1 ]; then echo "Refreshed desktop collection"; fi

   ############################################################################
   # Create console instance's data attributes
   ############################################################################

   # "Properties" window values

   idlattr -t -a $consoleOID java_path      string '""'
   idlattr -t -a $consoleOID java_classpath string '""'
   idlattr -t -a $consoleOID clargs         string '""'

   # "hard wired" values

   idlattr -t -a $consoleOID key            string '"'$tdiKey'"'

   if [ $DBUG -eq 1 ]; then echo "Set attributes"; fi

else

   echo "$label instance already exists with OID=$consoleOID"

fi

$root/bin/installTConsolePerm.sh

#
# remove script
#
if [ -f $root/bin/remove ] ; then
  if [ -f $root2/remove ] ; then
    rm $root2/remove
  fi
  cp $root/bin/remove $root2/remove.sh
  mv $root2/remove.sh $root2/remove
  mv $root/bin/remove $root/bin/tserver.rm.sh
  chmod 754 $root2/remove
fi

echo "Completed installation of the \"$label\" console icon"
