#!/bin/sh

set +e 

###############################################################################
# Licensed Materials - Property of Tivoli Systems
# 5697-GEM
# (C) COPYRIGHT Tivoli Systems, an IBM Company 1998
# All rights reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################
#
#  Install designated base console "item"
###############################################################################
DBUG=1

echo "Invocation: $0 $@"
 
###############################################################################
# We MUST be passed the ID of the product "item" to be installed
###############################################################################
item=$1
item=${item:?"product \"item\" not supplied!"}

###############################################################################
# Run the standard script to set up the Tivoli environment
###############################################################################
if [ -n "$windir" ] ; then
      WINOS=`echo $windir | awk /:/'{ print substr($1,4) }'`
   WINDRIVE=`echo $windir | awk /:/'{ print substr($1,1,2) }'`
fi

if [ -n "$WINOS" ]
then source $WINDRIVE/$WINOS/system32/drivers/etc/Tivoli/setup_env.sh
else . /etc/Tivoli/setup_env.sh
fi

###############################################################################
# Locate GEM installation "root"
###############################################################################
root=$BINDIR/../generic_unix/TDS/client
  
###############################################################################
# The base product properties file must exist
###############################################################################
prodProp="$root/bin/baseProduct.properties"

if [ ! -e $prodProp ] ; then
  echo 
  echo "The base product properties file does not exist!"
  echo "==> $prodProp" 
  exit 1 
fi                             

if [ $DBUG -eq 1 ]
then
  echo "---------------------------------------------------------"
  cat $prodProp    # dump contents for debugging
  echo "---------------------------------------------------------"
  echo
fi
                             
###############################################################################
# Load Tivoli Desktop Installation values from the product properties file
###############################################################################
 tdiPatchID=`awk -F= /^$item/'       {print $2}' $prodProp`

tdiAboutCat=`awk -F= /^tdiAboutCat/' {print $2}' $prodProp`
 
###############################################################################
# Establish runtime constants
###############################################################################
aboutCat="$root/bin/$tdiAboutCat"

###############################################################################
# Establish console class' "About" support
###############################################################################
wsetabout $aboutCat 1 $tdiPatchID
   
echo "Set About info for $tdiPatchID from $aboutCat"
