#!/bin/sh

###############################################################################
# Licensed Materials - Property of Tivoli Systems
# 5697-GEM
# (C) COPYRIGHT Tivoli Systems, an IBM Company 1997, 1999
# All rights reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################
#
# Open the console on the current managed node
#
# Make sure nothing is printed to the standard output or standard error, 
# especially when running on Windows NT.  Print everything to a logfile.  
#
# Shell commands can be grouped in () or {} and the output of whole groups 
# redirected to the logfile (as done below)
###############################################################################
DBUG=0
STATUS=1    

###############################################################################
# Run the standard script to set up the Tivoli environment
###############################################################################
if [ -n "$windir" ] ; then
      WINOS=`echo $windir | awk /:/'{ print substr($1,4) }'`
   WINDRIVE=`echo $windir | awk /:/'{ print substr($1,1,2) }'`
fi

if [ -n "$windir" ]; then
    source $WINDRIVE/$WINOS/system32/drivers/etc/Tivoli/setup_env.sh
else
    . /etc/Tivoli/setup_env.sh
fi

###############################################################################
# Establish runtime constants
###############################################################################
OWNER=$1
ID=$2

CLIENT_DIR=$BINDIR/../generic_unix/TDS/client
           
ICON_NAME=`idlattr -t -g $OWNER label string | sed 's/"//g'`

LOGFILE=`wtemp -s`$ICON_NAME.log
      
###############################################################################
# Log what's going on as we start this console
#
# Notes:
# - re-create log file on EACH use
# - capture both STDOUT and STDERR in the log file
###############################################################################
( 
  
echo "Opened...........`date`"
echo "Script...........$0"
echo "Working Dir......`pwd`"
echo "INTERP...........$INTERP"
echo "Console..........$ICON_NAME"
echo "Install root.....$CLIENT_DIR"
echo

###############################################################################
# Load current console properties
#
# Note: the SED call removes the quotes from the IDLATTR returned string
#       (like "local trace")
###############################################################################
   CLIENT_CLARGS=`idlattr -t -g $OWNER clargs         string | sed 's/"//g'`
     CLIENT_PATH=`idlattr -t -g $OWNER java_path      string | sed 's/"//g'`   
CLIENT_CLASSPATH=`idlattr -t -g $OWNER java_classpath string | sed 's/"//g'`
      CLIENT_KEY=`idlattr -t -g $OWNER key            string | sed 's/"//g'`

###############################################################################
# Auto-migrate pre-GEM 2.2 console icon, if necessary...
###############################################################################
if [ -z $CLIENT_KEY ]
then 
   CLIENT_KEY="gem"
   
   eval idlattr -t -s $OWNER key string \'\"$CLIENT_KEY\"\'                
   
   echo "Pre-GEM 2.2 console icon migrated..."
fi

echo "Prop(Path).......$CLIENT_PATH"            
echo "Prop(Args).......$CLIENT_CLARGS"
echo "Prop(Classpath)..$CLIENT_CLASSPATH"
echo "Prop(Key)........$CLIENT_KEY"
echo

if [ $STATUS -eq 1 ]
then 
   wstatusline "`date` Logging to $LOGFILE."
fi

if [ $DBUG -eq 1 ]
then 
   wstatusline "  J_CLASSPATH=$CLIENT_CLASSPATH, ARGS=$CLIENT_CLARGS";
   wstatusline "  OWNER=$OWNER, ID=$ID"; 
fi

###############################################################################
# For Intel platforms (Windows NT), the $INTERP variable will begin with 'w32'.
# On this platform only, the CLASSPATH variable must use Intel-style backslashes
# instead of forward slashes for directory name separators, and semicolons for
# path element separators.  Also for this platform only, the wrunui program must
# be run to display the Java client.  This is a special version of wrunui created
# by Jim Kelton in Austin which requires the '-e' argument.  This version does not
# exist in TME 3.1 and so must be shipped with the IHS client.  For this reason,
# the IHS client bin directory must be ahead of any Tivoli directories in the PATH
# variable.
###############################################################################
case "$INTERP" in
  w32* )
  
    CLIENT_PATH=`echo $CLIENT_PATH | tr ';' ':'`
    export PATH="$CLIENT_DIR/bin:$CLIENT_PATH:$PATH"
  
    TCONSOLE_CLASSPATH=`$CLIENT_DIR/bin/convertpath.sh $CLIENT_CLASSPATH`
    export TCONSOLE_CLASSPATH
   
    # make value available to tconsole.sh
    export WRUNUI="$BINDIR/bin/wrunui -e"
    ;;

  * )
  
    CLIENT_PATH=`echo $CLIENT_PATH | tr ';' ':'`
    PATH="$CLIENT_DIR/bin:$CLIENT_PATH:$PATH"; export PATH
    
    TCONSOLE_CLASSPATH=`echo $CLIENT_CLASSPATH | tr ';' ':'`
    export TCONSOLE_CLASSPATH
    ;;
esac

###############################################################################
# Actually run the console
# 
# Note: we are logging stdout/stderr to console specific log file
###############################################################################
echo "Used TCONSOLE_CLASSPATH...$TCONSOLE_CLASSPATH"
echo "Used PATH.................$PATH"
echo "UI program................$WRUNUI"
echo 

ALI=`wlookup TME_server`
ID=`objcall $ALI get_identity`

#############################################################################
# Attempt to get the string representing the administrator name from $ID.
# Normally, this is just the first word in the string, as in:
#
#   Root 1921060796.1.178#TMF_Administrator::Configuration_GUI#
#
# But, some administrator entries are in the format:
#
#   RWGILBER\Administrator@rwgilber.raleigh.ibm.com 1921060796.1.178#TMF...
#
# For these entries, strip out everything before the backslash (\) and after
# the '@' symbol.
#############################################################################
NAMEPART1=`echo $ID | awk '{ print $1 }'`
NAME=`echo $NAMEPART1 | sed -e 's/@.*$//' -e 's/^.*[\\]//'`
 
USER_ARGS="-user $NAME"

RUN_CMD="$CLIENT_DIR/bin/tconsole.sh $CLIENT_DIR $USER_ARGS -key $CLIENT_KEY $CLIENT_CLARGS"

if [ $DBUG -eq 1 ]
then 
  wstatusline "  Command:   $RUN_CMD"
fi

echo "Command..........$RUN_CMD"
echo "***********************************************************************"

$RUN_CMD

if [ $STATUS -eq 1 ]
then 
  wstatusline "`date` Closing $LOGFILE."
fi

echo 
echo "***********************************************************************"
echo "Closed...........`date`"

) > $LOGFILE 2>&1    
