#!/bin/sh

###############################################################################
# Licensed Materials - Property of Tivoli Systems
# 5697-GEM
# 5697-B82
# (C) COPYRIGHT Tivoli Systems, an IBM Company 1997, 2001
# All rights reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################
#
# Run a Tivoli Topology console Java application on:
#
#   * supported Unix platforms
#   * Windows NT with Tivoli Framework (i.e. "bash" is available)
# 
# Command Line Arguments:
# =======================
# $1 - required; fully qualified installation path specification
#                  example:  NT:   C:\Tivoli\bin\generic_unix\TDS\client
#                            Unix: /usr/local/Tivoli/bin/generic_unix/TDS/client
#                  could be: NT:   %bindir%\..\generic_unix\TDS\client
#                            Unix: $BINDIR/../generic_unix/TDS/client
#
# $2 - required; package qualified class name (Ex. com.tivoli.ihs.nmc.server.IhsHttpParse)
# $3 - optional; additional class command line argument
# ...
# $n - optional; additional class command line argument
# 
# Assumptions
# ===========
# TCONSOLE_CLASSPATH - optional; Java code library(s) placed at end
#                                of CLASSPATH 
# TCONSOLE_JAVAOPTS  _ optional; command line arg(s) for Java 
# TCONSOLE_BACKDOOR  - optional; Java code library(s) placed at front
#                                of CLASSPATH 
###############################################################################

###############################################################################
# The installation "root" and class name must be specified
###############################################################################
if [ -z "$1" ]; then
  echo "Usage: $0 installation-path classname [ args ]"
  exit 1
fi

if [ -z "$2" ]; then
  echo "Usage: $0 installation-path classname [ args ]"
  exit 1
fi

###############################################################################
# Isolate command line args
###############################################################################
IPATH=$1		     # install path		
shift

CNAME=$1                     # class name
shift

ARGS="$*"                    # the rest are args

###############################################################################
# Create JAVA_LIB and JAVA_CMD environment variable accourding to INTERP 
# NOTE: JRE or JDK must be installed into $IPATH/../../../[INTERP]/TDS/java
###############################################################################
JAVA_LIB=""
JAVA_CMD=""

###  AIX script logic changed for Java 2 JRE 1.3.0:
###  IJAVA must be hardcoded to find libjvm.a and
###  java subdirectory path must be /TDS/jre not /TDS/java
###  since java JVM needs absolute /jre for /jre/bin and
###  /jre/lib otherwise it cannot open javalib.a
###  (jim dramis 11/6/2000)

if [ -d $IPATH/../../../aix4-r1/TDS/jre ] ; then
{
	IJAVA="/usr/local/Tivoli/bin/aix4-r1/TDS/jre"
        PATH="$IJAVA/bin:$PATH"
        export PATH
        JAVA_CMD="$IJAVA/bin/java"
        JAVA_LIB="$IJAVA/lib/rt.jar;$IJAVA/lib/i18n.jar" 
}
elif [ -d $IPATH/../../../w32-ix86/TDS/java ] ; then
{
        IJAVA="$IPATH\..\..\..\w32-ix86\TDS\java"
        PATH="$IJAVA\bin;$PATH"
        export PATH
        JAVA_CMD="$IJAVA\bin\java"
        JAVA_LIB="$IJAVA\lib\rt.jar;$IJAVA\lib\i18n.jar"
}
elif [ -d $IPATH/../../../os2-ix86/TDS/java ] ; then
{
        IJAVA="$IPATH\..\..\..\os2-ix86\TDS\java"
        PATH="$IJAVA\bin;$PATH"
        export PATH
        JAVA_CMD="$IJAVA\bin\java"
        JAVA_LIB="$IJAVA\lib\rt.jar;$IJAVA\lib\i18n.jar"
}
elif [ -d $IPATH/../../../solaris2/TDS/java ] ; then
{
        IJAVA="$IPATH/../../../solaris2/TDS/java"
        PATH="$IJAVA/bin:$PATH"
        export PATH
        JAVA_CMD="$IJAVA/bin/java"
        JAVA_LIB="$IJAVA/lib/rt.jar:$IJAVA/lib/i18n.jar"
}
elif [ -d $IPATH/../../../hpux10/TDS/java ] ; then
{
        IJAVA="$IPATH/../../../hpux10/TDS/java"
        PATH="$IJAVA/bin:$PATH"
        export PATH
        JAVA_CMD="$IJAVA/bin/java"
        JAVA_LIB="$IJAVA/lib/rt.jar:$IJAVA/lib/i18n.jar"
}
elif [ -d $IPATH/../../../hpux11/TDS/java ] ; then
{
        IJAVA="$IPATH/../../../hpux11/TDS/java"
        PATH="$IJAVA/bin:$PATH"
        export PATH
        JAVA_CMD="$IJAVA/bin/java"
        JAVA_LIB="$IJAVA/lib/rt.jar:$IJAVA/lib/i18n.jar"
}
elif [ -d $IPATH/../../../linux-ix86/TDS/java ] ; then
{
        IJAVA="$IPATH/../../../linux-ix86/TDS/java"
        PATH="$IJAVA/bin:$PATH"
        export PATH
        JAVA_CMD="$IJAVA/bin/java"
        JAVA_LIB="$IJAVA/lib/rt.jar:$IJAVA/lib/i18n.jar"
}
else
	echo 'Error: Unable to determine integrated JRE.'
        ls -d $IPATH/../../../
	exit 1
fi

###############################################################################
# Determine if running on Unix or Windows NT
#
# On Windows NT, the CLASSPATH variable must use Intel-style backslashes
# instead of forward slashes for directory name separators, and semicolons for
# path element separators. 
###############################################################################
J_RUN_PGM=""

if [ -n "$windir" ] ; then
  
   # convert any Unix directory separators to Windows equivalent before
   # creating composite items 
   
   IPATH=`echo $IPATH | tr '/' '\\\'`
   
     LIB="$IPATH\\lib"

  CP_RUN="$TCONSOLE_BACKDOOR;$LIB\\ihseuc.jar;$JAVA_LIB;$TCONSOLE_CLASSPATH"
   
  JAVA_OPTS="-mx45M -ms16M $TCONSOLE_JAVAOPTS"

else

     LIB="$IPATH/lib"

  CP_RUN="$TCONSOLE_BACKDOOR:$LIB/ihseuc.jar:$JAVA_LIB:$TCONSOLE_CLASSPATH"

  JAVA_OPTS="-mx45M -ms16M $TCONSOLE_JAVAOPTS"

  ############################################################################
  # On Unix systems, we must be sure that the display is exported
  # or else the console won't start...
  #
  # if XHOST fails, abort now to avoid "hanging" below when java started
  ############################################################################
  if [ ! "xhost +" ] 
  then
    echo "Unable to start this console due to XHOST failure!"
    echo "Current PATH: $PATH"
    exit 1 
  fi
fi

J_RUN="$J_RUN_PGM $JAVA_CMD $JAVA_OPTS -classpath $CP_RUN $CNAME $ARGS"

############################################################################
# Run the specified Java class
############################################################################
echo $J_RUN
     $J_RUN

############################################################################
# Let the Java program's exit code be returned to whoever invoked us
############################################################################
# exit $?
