#!/bin/sh

#*************************************************************************
# Licensed Materials - Property of Tivoli Systems
# 5697-B82
# (C) Copyright Tivoli Systems 2001
# All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#*************************************************************************

clear 

DEBUG=-Dverbose

DEFAULT_INSTALL_ROOT=/usr/local/Tivoli/bin

ORIG_TCONSOLE_JAVAOPTS=$TCONSOLE_JAVAOPTS

if [ "$NV390_TCONSOLE_INSTALL_ROOT" ]
then
   cd ${NV390_TCONSOLE_INSTALL_ROOT}/generic_unix/TDS/client/bin
else
   echo NV390_TCONSOLE_INSTALL_ROOT environment variable not found!
   
   if [ -d $DEFAULT_INSTALL_ROOT ]
   then
      echo 
      echo Found default value of $DEFAULT_INSTALL_ROOT
      echo
      cd ${DEFAULT_INSTALL_ROOT}/generic_unix/TDS/client/bin
   else
      echo Default install root not found. Aborting!
      exit 1
   fi
fi

# **************************************************************************
# *  Parse the command line arguments
# **************************************************************************
if [ $# -gt 1 ] # if there are two or more command line arguments
then 
   #if [ $1 = "default" ] 
   #   then 
   #      PORT=
   #   else
   PORT=$1
   #fi
   
   shift   
   
   RES=$1
   shift 
     
   ARGS="$*"                    # the rest are args
   
   echo "Using these values:"
   echo "-------------------"
   echo "PORT: $PORT"
   echo " RES: $RES "
   echo "ARGS: $ARGS"
   
   # *********************************************************************
   # *  Single shot test to see if the NMC web server is already running
   # *********************************************************************
   TCONSOLE_JAVAOPTS=$DEBUG
   export TCONSOLE_JAVAOPTS
   
   ./tapp.sh .. com.tivoli.ihs.cli.nmcRunning $PORT
   
   ReturnCode=$?
      
   if [ $ReturnCode != 0 ]
      then     
      # *****************************************************************
      # *  Launch the console forcing the start of the HTTP web server
      # *****************************************************************
      TCONSOLE_JAVAOPTS=$ORIG_TCONSOLE_JAVAOPTS
      export TCONSOLE_JAVAOPTS

      exec xterm -e $NV390_TCONSOLE_SCRIPT .. -httpport $PORT $ARGS &
       
      # *****************************************************************
      # *  Poll for the NMC web server to start running
      # *****************************************************************
      TCONSOLE_JAVAOPTS="-Dpoll $DEBUG" 
      export TCONSOLE_JAVAOPTS 
      
      ./tapp.sh .. com.tivoli.ihs.cli.nmcRunning $PORT
      
      # *****************************************************************
      # *  Able to connect to the NMC web server?
      # *****************************************************************
      if [ $? != 0 ]
         then                                                   
         echo Unable to connect to the NMC web server...
         exit 1
      fi
   fi
      
   # *********************************************************************
   #*  Locate the specified resource
   # *********************************************************************
   TCONSOLE_JAVAOPTS=$DEBUG 
   export TCONSOLE_JAVAOPTS 

   ./tapp.sh .. com.tivoli.ihs.cli.locRes $RES $PORT

# ****************************************************
# Display "usage"
# ****************************************************
else 
 clear
 
 echo "Usage"
 echo "-----"
 echo "tlocRes.sh port name [ args ]"
 echo ""
 echo "Purpose"
 echo "-------"
 echo "Initiate a 'Locate Resource' request to the NMC Console Web Server"
 echo "running on the same machine.  If necessary, the NMC Console is started."
 echo ""
 echo "Arguments"
 echo "---------"
 echo "port - required; NMC console web server port number"
#echo "                 examples: default = use default port number"
 echo "                           8080    = specific port number"
 echo "name - required; name of resource to locate"
 echo "args - optional; additional TCONSOLE script command line arguments"
 echo "                 used if the NMC console must be started"
 echo ""
 echo "Required NMC Environment Variables"
 echo "----------------------------------"
 echo "NV390_TCONSOLE_INSTALL_ROOT...installation root path [$NV390_TCONSOLE_INSTALL_ROOT]"
 echo "NV390_TCONSOLE_SCRIPT.........console start script   [$NV390_TCONSOLE_SCRIPT]"
fi
