#!/bin/sh

###############################################################################
# Licensed Materials - Property of Tivoli Systems
# 5697-GEM
# (C) COPYRIGHT Tivoli Systems, an IBM Company 1997, 1998
# All rights reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################
#
# UnInstall the specified console icon from the Tivoli desktop
###############################################################################
echo "Invocation: $0 $@"

###############################################################################
# Print "usage" if no command line arg(s) specified
###############################################################################
if [ $# -eq 0 ]
then
  echo "Usage: uninstallTConsole <Class>_<Node>"
  exit 1
fi

echo "Requested to delete the $1 console icon..."

###############################################################################
# Split console name into "class" and "node" parts
############################################################################
if [ "$INTERP" = "solaris2" ] ; then
  class=`echo $1 | awk -F 'BEGIN { FS = "_" } {print $1}'`
  node=`echo $1 | awk -F 'BEGIN { FS = "_" } {print $2}'`
else
  class=`echo $1 | awk -F_ //'{print $1}'`
  node=`echo $1 | awk -F_ //'{print $2}'`
fi

echo
echo "Class=$class"
echo " Node=$node"
echo

###############################################################################
# Does this console icon exist?
############################################################################
iconOID=`wlookup -r $class $1 2> /dev/null`

if [ -n "$iconOID" ]
then
   ######################################################################
   # Delete the desktop icon object
   ######################################################################
   objcall $iconOID remove

   echo "Console icon \"$1\" with OID=$iconOID has been deleted"

   ######################################################################
   # Refresh the desktop so visually removed
   ######################################################################
   ALI=`wlookup TME_server`
    ID=`objcall $ALI get_identity`

   ROOTADMIN=`echo $ID | awk '{print $2}'`

   idlcall $ROOTADMIN TMF_TGC::GenericCollection::refresh_collection refresh_collection
else
   echo "Console icon \"$1\" does not exist!"
fi

############################################################################
# Does the console class exist?
############################################################################
classOID=`wlookup -r Classes $class 2> /dev/null`

if [ -n "$classOID" ]
then
  ############################################################################
  # Yes, if there are NO more console icons instances in TMR
  # then the console class object(s) should be removed
  ############################################################################
  count=`wlookup -r $class -a | wc -l`

  echo "$count \"$class\" instances exist..."

  if [ $count -eq 0 ]
  then
    ############################################################################
    # Remove the console class object
    ############################################################################
    objcall $classOID remove

    wregister -u -r Classes $class

    idlcall -T top `wlookup NameRegistry` TMF_TNR::Resource::remove ''\"$class\" ' TRUE'

    echo "Class \"$class\" with OID=$classOID deleted"

    ############################################################################
    # Remove the console class presentation
    ############################################################################
    presOID=`wlookup -r Presentation $class 2> /dev/null`

    echo "\"$class\" presentation object has OID=$presOID"

    if [ -n "$presOID" ]
    then
       objcall $presOID remove
    fi
  fi
else
   echo "Console class \"$class\" does not exist!"
fi

echo "Completed deletion of the \"$1\" console icon"
